--[[
AdiBags - Legion
by Zottelchen
version: 2.0.1
Items from the Legion expansion.
]]

local addonName, addon = ...
local AdiBags = LibStub("AceAddon-3.0"):GetAddon("AdiBags")

local L = addon.L
local MatchIDs
local Result = {}

local function AddToSet(...)
  local Set = {}
  for _, l in ipairs({ ... }) do
    for _, v in ipairs(l) do
      Set[v] = true
    end
  end
  return Set
end

-- Champion Equipment
local ChampionEquipment_IDs = {
  138413, -- Boots of Efficiency
  138416, -- Xavier's Curiosity
  139419, -- Golden Banana
  139428, -- A Master Plan
  139792, -- Fruitful Bauble
  139795, -- Draught of Courage
  139799, -- Pathfinder's Saddle
  139801, -- Lucky Doodad
  139802, -- Auspicious Fetish
  139804, -- Glacial Fang
  139808, -- Curio of Abundant Happiness
  139809, -- Elixir of Plenty
  139811, -- Necklace of Endless Memories
  139812, -- Potion of Triton
  139813, -- Swift Boots
  139814, -- Carrot on a Stick
  139816, -- Well-Worn Stone
  139819, -- Embers of the Firelands
  139821, -- Omen's Bidding
  139822, -- Dust of Azeroth
  139823, -- Nightmare's End
  139824, -- Light's Haven
  139825, -- Tome of Secrets
  139826, -- Eltrig's Grace
  139827, -- Brooch of Endless Dreams
  139828, -- Queen's Feathers
  139829, -- Potion of Sacrifice
  139830, -- Demon in a Box
  139831, -- Smoke Grenades
  139832, -- Sleep Potion
  139833, -- Leech Brew
  139834, -- Vanishing Dust
  139835, -- Marauder's Vestige
  139836, -- Shadow Relic
  139837, -- Demon's Sigil
  139838, -- Essence of Malice
  139839, -- Voodoo Post
  139840, -- Earthly Pincer
  139841, -- Totem of the Earth
  139842, -- Furious Charge
  139843, -- Conjurer's Bauble
  139844, -- Arcanist's Trifle
  139845, -- Band of Primordial Strength
  139846, -- Highborne Bauble
  139847, -- Bow of Ancient Kings
  139848, -- Seeker's Scrip
  139849, -- Windrunner's Gift
  139850, -- Cloak of Deception
  139851, -- Valarjar's Might
  139852, -- War Banner
  139853, -- Axe of the Valkyra
  139854, -- Skull of a Fallen Foe
  139855, -- Skull of Embrace
  139856, -- Demonic Brew
  139857, -- Helm of Command
  139858, -- Black Harvest Curio
  139859, -- Chi Empowered Jewel
  139860, -- Tea of Blessing
  139861, -- Mogu Madstone
  139862, -- Bell of Fury
  139863, -- Elune's Sight
  139864, -- Scroll of Growth
  139865, -- Glowing Token
  139866, -- Forest Ember
  139867, -- Justice Hammer
  139868, -- Light's Shield
  139869, -- Libram of Enlightenment
  139870, -- Silver Hand Ornament
  139871, -- Holy Figurine
  139872, -- Light's Command
  139873, -- Bottled Sanity
  139874, -- Sanity Edge
  139875, -- Undead Token
  139876, -- Rune of Reckoning
  139877, -- Death's Touch
  139878, -- Relic of the Ebon Blade
  139879, -- Crate of Champion Equipment
  140156, -- Blessing of the Order
  140571, -- Potion of Energy
  140572, -- Hasty Pocketwatch
  140573, -- Elixir of Overwhelming Focus
  140581, -- Sturdy Hiking Boots
  140582, -- Bottomless Flask
  140583, -- Vial of Timeless Breath
  140749, -- Horn of Winter
  140760, -- Libram of Truth
  143605, -- Strange Ball of Energy
  143852, -- Lucky Rabbit's Foot
  147552, -- Embers of the Firelands
  147553, -- Shard of Twisting Nether
  147554, -- Harpy Feather
  147555, -- Vial of Sight
  147556, -- Cloak of Concealment
  147557, -- Fel Imp Tooth
  147558, -- Pouch of Wonder
  147559, -- Ward of Infinite Fury
  147560, -- Horn of Rage
  147561, -- Relic of Demonic Influence
  147563, -- Stone Totem
  147564, -- Diamond Stone
  147565, -- Book of Lost Sermons
  147566, -- Horn of Valor
  147567, -- Soothing Focus
  147568, -- Essence of Nether
  147569, -- Arcane Trap
  147570, -- Dreamgrove Leaf
  147571, -- Demonic Standard
  147572, -- Sigil of Ebon Frost
  147905, -- Chest of Champion Equipment
  152437, -- Viscid Demon Blood
  152438, -- Krokul Sledgehammer
  152439, -- Pit Lord Tusk
  152440, -- Void-Touched Arinor Blossom
  152441, -- Satchel of Lucidity
  152442, -- Impervious Shadoweave Hood
  152443, -- Sanctified Armaments of the Light
  152444, -- Exalted Xenedar Hammer
  152445, -- Memento of the Lightforged
  152446, -- Writ of Holy Orders
  152447, -- Lightburst Charge
  152448, -- Praetorium Tome of Arcana
  152449, -- Azurelight Candelabra
  152450, -- Augari Censorite Staff
  152451, -- Volatile Stygian Scroll
  152452, -- Pulsing Wrathguard Skull
  152453, -- Fel-Infused Legion Effigy
  152454, -- Darklost Claw
  152927, -- Serrated Stone Axe
  152928, -- Archaic Seerstone
  152929, -- Pronged Ridgestalker Spear
  152930, -- Vilefiend-Spine Whip
  152931, -- Xenic Tincture
  152932, -- Runewarded Lightblade
  152933, -- Shadowguard Void Effusion
  152934, -- Shadow-Soaked Stalker Heart
  152935, -- Wakener's Bauble
  152936, -- Azurelight Sapphire
  153132, -- Coffer of Argus Equipment
}

-- Champion Upgrade Tokens
local ChampionUpgradeTokens_IDs = {
  136412, -- Heavy Armor Set
  137207, -- Fortified Armor Set
  137208, -- Indestructible Armor Set
  138410, -- Summoning Portal
  138412, -- Iresoul's Healthstone
  138883, -- Meryl's Conjured Refreshment
  139177, -- Shattered Soul
  139376, -- Healing Well
  139418, -- Healing Stream Totem
  139420, -- Wild Mushroom
  139670, -- Scream of the Dead
  140922, -- Imp Pact
  140923, -- Ghoul Tombstone
  140924, -- Ashtongue Beacon
  140925, -- Enchanted Bark
  140926, -- Bowmen's Orders
  140927, -- Water Globe
  140928, -- Ox Initiate's Pledge
  140929, -- Squire's Oath
  140930, -- Acolyte's Vows
  140931, -- Bandit Wanted Poster
  140932, -- Earthen Mark
  140933, -- Runed Aspirant's Band
  141028, -- Grimoire of Knowledge
  142209, -- Dinner Invitation
  143849, -- Summon Royal Guard
  143850, -- Summon Grimtotem Warrior
  147348, -- Bulky Armor Set
  147349, -- Spiked Armor Set
  147350, -- Invincible Armor Set
  151841, -- ERROR1
  151842, -- Krokul Armor Set
  151843, -- Eredath Armor Set
  151844, -- Xenedar Armor Set
  152095, -- Krokul Ridgestalker
  152096, -- Void-Purged Krokul
  152097, -- Lightforged Bulwark
  153005, -- Relinquished Armor Set
  153006, -- Grimoire of Lost Knowledge
}

-- Fishing Bait
local FishingBait_IDs = {
  133701, -- Skrog Toenail
  133702, -- Aromatic Murloc Slime
  133703, -- Pearlescent Conch
  133704, -- Rusty Queenfish Brooch
  133705, -- Rotten Fishbone
  133706, -- Mossgill Bait
  133707, -- Nightmare Nightcrawler
  133708, -- Drowned Thistleleaf
  133709, -- Funky Sea Snail
  133710, -- Salmon Lure
  133711, -- Swollen Murloc Egg
  133712, -- Frost Worm
  133713, -- Moosehorn Hook
  133714, -- Silverscale Minnow
  133715, -- Ancient Vrykul Ring
  133716, -- Soggy Drakescale
  133717, -- Enchanted Lure
  133719, -- Sleeping Murloc
  133720, -- Demonic Detritus
  133721, -- Message in a Beer Bottle
  133722, -- Axefish Lure
  133723, -- Stunned, Angry Shark
  133724, -- Decayed Whale Blubber
}

-- Rare Fish
local RareFish_IDs = {
  133725, -- Leyshimmer Blenny
  133726, -- Nar'thalas Hermit
  133727, -- Ghostly Queenfish
  133728, -- Terrorfin
  133729, -- Thorned Flounder
  133730, -- Ancient Mossgill
  133731, -- Mountain Puffer
  133732, -- Coldriver Carp
  133733, -- Ancient Highmountain Salmon
  133734, -- Oodelfjisk
  133735, -- Graybelly Lobster
  133736, -- Thundering Stormray
  133737, -- Magic-Eater Frog
  133738, -- Seerspine Puffer
  133739, -- Tainted Runescale Koi
  133740, -- Axefish
  133741, -- Seabottom Squid
  133742, -- Ancient Black Barracuda
  139652, -- Leyshimmer Blenny
  139653, -- Nar'thalas Hermit
  139654, -- Ghostly Queenfish
  139655, -- Terrorfin
  139656, -- Thorned Flounder
  139657, -- Ancient Mossgill
  139658, -- Mountain Puffer
  139659, -- Coldriver Carp
  139660, -- Ancient Highmountain Salmon
  139661, -- Oodelfjisk
  139662, -- Graybelly Lobster
  139663, -- Thundering Stormray
  139664, -- Magic-Eater Frog
  139665, -- Seerspine Puffer
  139666, -- Tainted Runescale Koi
  139667, -- Axefish
  139668, -- Seabottom Squid
  139669, -- Ancient Black Barracuda
}

-- Ancient Mana
local AncientMana_IDs = {
  129036, -- ERROR1
  129097, -- ERROR1
  129098, -- ERROR1
  136806, -- Glass of Arcwine
  137010, -- Half-Full Bottle of Arcwine
  139786, -- Ancient Mana Crystal
  139884, -- ERROR1
  139889, -- ERROR1
  139890, -- Ancient Mana Gem
  140234, -- Selentia's Mana-Infused Brooch
  140235, -- Small Jar of Arcwine
  140236, -- A Mrglrmrl Mlrglr
  140239, -- Excavated Highborne Artifact
  140240, -- Enchanted Moonwell Waters
  140242, -- Astromancer's Compass
  140243, -- Azurefall Essence
  140245, -- The Tidemistress' Enchanted Pearl
  140246, -- Arc of Snow
  140248, -- Master Jeweler's Gem
  140390, -- Red Or'ligai Egg
  140399, -- Yellow Or'ligai Egg
  140401, -- Blue Or'ligai Egg
  140402, -- Green Or'ligai Egg
  140403, -- Lylandre's Fel Crystal
  140404, -- Intact Guardian Core
  140405, -- Illusion Matrix Crystal
  140406, -- Primed Arcane Charge
  140732, -- ERROR1
  140733, -- ERROR1
  140734, -- ERROR1
  140735, -- ERROR1
  140949, -- Onyx Or'ligai Egg
  140953, -- ERROR1
  141655, -- Shimmering Ancient Mana Cluster
  143733, -- Ancient Mana Shards
  143734, -- Ancient Mana Crystal Cluster
  143735, -- Ancient Mana Shards
  143748, -- Leyscale Koi
}

-- Artifact Power
local ArtifactPower_IDs = {
  130152, -- Condensed Light of Elune
  131732, -- Purple Hills of Eredath
  131751, -- Fractured Portal Shard
  131753, -- Prayers to the Earthmother
  131763, -- Bundle of Trueshot Arrows
  131795, -- Nar'thalasian Corsage
  131802, -- Offering to Ram'Pag
  131808, -- Engraved Bloodtotem Armlet
  132897, -- Mandate of the Watchers
  132950, -- Petrified Snake
  136360, -- Crystalline Demonic Eye
  138480, -- Black Harvest Tome
  138487, -- Shinfel's Staff of Torment
  138732, -- History of the Blade
  138781, -- Brief History of the Aeons
  138782, -- Brief History of the Ages
  138783, -- Glittering Memento
  138784, -- ERROR1
  138785, -- Adventurer's Resounding Glory
  138786, -- Talisman of Victory
  138812, -- Adventurer's Wisdom
  138813, -- Adventurer's Resounding Renown
  138814, -- Adventurer's Renown
  138816, -- Adventurer's Glory
  138839, -- Valiant's Glory
  138864, -- Skirmisher's Advantage
  138865, -- Gladiator's Triumph
  138880, -- Soldier's Grit
  138881, -- Soldier's Glory
  138885, -- Treasure of the Ages
  138886, -- Favor of Valarjar
  139413, -- ERROR1
  139506, -- Greater Glory of the Order
  139507, -- Cracked Vrykul Insignia
  139508, -- Dried Worldtree Seeds
  139509, -- Worldtree Bloom
  139510, -- Black Rook Soldier's Insignia
  139511, -- Hallowed Runestone
  139512, -- Sigilstone of Tribute
  139591, -- Stolen Tome of Artifact Lore
  139608, -- Brittle Spelltome
  139609, -- Depleted Cadet's Wand
  139610, -- Musty Azsharan Grimoire
  139611, -- Primitive Roggtotem
  139612, -- Highmountain Mystic's Totem
  139613, -- Tale-Teller's Staff
  139614, -- Azsharan Manapearl
  139615, -- Untapped Mana Gem
  139616, -- Dropper of Nightwell Liquid
  139617, -- Ancient Warden Manacles
  140176, -- Accolade of Victory
  140237, -- Iadreth's Enchanted Birthstone
  140238, -- Scavenged Felstone
  140241, -- Enchanted Moonfall Text
  140244, -- Jandvik Jarl's Pendant Stone
  140247, -- Mornath's Enchanted Statue
  140250, -- Ingested Legion Stabilizer
  140251, -- Purified Satyr Totem
  140252, -- Tel'anor Ancestral Tablet
  140254, -- The Seawarden's Beacon
  140255, -- Enchanted Nightborne Coin
  140304, -- Activated Essence
  140305, -- Brimming Essence
  140306, -- Mark of the Valorous
  140307, -- Heart of Zin-Azshari
  140310, -- Crude Statuette
  140322, -- Trainer's Insight
  140349, -- Spare Arcane Ward
  140357, -- Fel Lava Rock
  140358, -- Eredar Armor Clasp
  140359, -- Darkened Eyeball
  140361, -- Pulsating Runestone
  140364, -- Frostwyrm Bone Fragment
  140365, -- Dried Stratholme Lily
  140366, -- Scarlet Hymnal
  140367, -- Tattered Sheet Music
  140368, -- Tarnished Engagement Ring
  140369, -- Scrawled Recipe
  140370, -- Amber Shard
  140371, -- Letter from Exarch Maladaar
  140372, -- Ancient Artificer's Manipulator
  140373, -- Ornamented Boot Strap
  140374, -- Jagged Worgen Fang
  140377, -- Broken Medallion of Karabor
  140379, -- Broken Warden Glaive Blade
  140380, -- Swiftflight's Tail Feather
  140381, -- Jandvik Jarl's Ring, and Finger
  140382, -- Tiny War Drum
  140383, -- Glowing Cave Mushroom
  140384, -- Azsharan Court Scepter
  140385, -- Legion Pamphlet
  140386, -- Inquisitor's Shadow Orb
  140387, -- Bracer Gemstone
  140388, -- Falanaar Gemstone
  140389, -- Petrified Flame
  140391, -- Argussian Diamond
  140392, -- Safety Valve
  140393, -- Repentia's Whip
  140396, -- Friendly Brawler's Wager
  140409, -- Tome of Dimensional Awareness
  140410, -- Mark of the Rogues
  140421, -- Ancient Qiraji Idol
  140422, -- Moonglow Idol
  140444, -- Dream Tear
  140445, -- Arcfruit
  140459, -- Moon Lily
  140460, -- Thisalee's Fighting Claws
  140461, -- Battered Trophy
  140462, -- Draketaming Spurs
  140463, -- Broken Eredar Blade
  140466, -- Corroded Eternium Rose
  140467, -- Fel-Infused Shell
  140468, -- Eagle Eggshell Fragment
  140469, -- Felslate Arrowhead
  140470, -- Ancient Gilnean Locket
  140471, -- Lord Shalzaru's Relic
  140473, -- Night-forged Halberd
  140474, -- Nar'thalas Pottery Fragment
  140475, -- Morning Glory Vine
  140476, -- Astranaar Globe
  140477, -- Inert Ashes
  140478, -- Painted Bark
  140479, -- Broken Legion Communicator
  140480, -- Drained Construct Core
  140481, -- Shimmering Hourglass
  140482, -- Storm Drake Fang
  140484, -- Well-Used Drinking Horn
  140485, -- Duskpelt Fang
  140486, -- Storm Drake Scale
  140487, -- War-Damaged Vrykul Helmet
  140488, -- Huge Blacksmith's Hammer
  140489, -- Ettin Toe Ring
  140490, -- Wooden Snow Shoes
  140491, -- Stolen Pearl Ring
  140492, -- Gleaming Glacial Pebble
  140494, -- Eredar Tail-Cuff
  140497, -- Bundle of Tiny Spears
  140498, -- Legion Admirer's Note
  140503, -- Blank To-Do List
  140504, -- Kvaldir Anchor Line
  140505, -- Sweaty Bandanna
  140507, -- Unlabeled Potion
  140508, -- Nightborne Artificer's Ring
  140509, -- Demon-Scrawled Drawing
  140510, -- Iron Black Rook Hold Key
  140511, -- Soul Shackle
  140512, -- Oversized Drinking Mug
  140513, -- Dreadlord's Commendation
  140515, -- Gift of Al'Akir
  140516, -- Elemental Bracers
  140517, -- Glory of the Order
  140518, -- Bottled Lightning
  140519, -- Whispering Totem
  140520, -- Amethyst Geode
  140521, -- Fire Turtle Shell Fragment
  140522, -- Petrified Spiderweb
  140523, -- Crimson Cavern Mushroom
  140524, -- Sharp Twilight Tooth
  140525, -- Obsidian Mirror
  140528, -- Dalaran Wine Glass
  140529, -- Felstalker's Ring
  140530, -- Opalescent Shell
  140531, -- Ravencrest Family Seal
  140532, -- Inscribed Vrykul Runestone
  140685, -- Enchanted Sunrunner Kidney
  140847, -- Ancient Workshop Focusing Crystal
  141023, -- Seal of Victory
  141024, -- Seal of Leadership
  141310, -- Falanaar Crescent
  141313, -- Manafused Fal'dorei Egg Sac
  141314, -- Treemender's Beacon
  141383, -- Crystallized Moon Drop
  141384, -- Emblem of the Dark Covenant
  141385, -- Tidestone Sliver
  141386, -- Giant Pearl Scepter
  141387, -- Emerald Bloom
  141388, -- Warden's Boon
  141389, -- Stareye Gem
  141390, -- The Corruptor's Totem
  141391, -- Ashildir's Unending Courage
  141392, -- Fragment of the Soulcage
  141393, -- Onyx Arrowhead
  141394, -- Plume of the Great Eagle
  141395, -- Stonedark's Pledge
  141396, -- The River's Blessing
  141397, -- The Spiritwalker's Wisdom
  141398, -- Blessing of the Watchers
  141399, -- Overcharged Stormscale
  141400, -- Underking's Fist
  141401, -- Renewed Lifeblood
  141402, -- Odyn's Watchful Gaze
  141403, -- Tablet of Tyr
  141404, -- Insignia of the Second Command
  141405, -- Senegos' Favor
  141638, -- Falanaar Scepter
  141639, -- Falanaar Orb
  141667, -- Ancient Keeper's Brooch
  141668, -- The Arcanist's Codex
  141669, -- Fel-Touched Tome
  141670, -- Arcane Trap Power Core
  141671, -- Moon Guard Focusing Stone
  141672, -- Insignia of the Nightborne Commander
  141673, -- Love-Laced Arrow
  141674, -- Brand of a Blood Brother
  141675, -- Deepwater Blossom
  141676, -- The Valewatcher's Boon
  141677, -- Key to the Bazaar
  141678, -- Night Devint: The Perfection of Arcwine
  141679, -- Cobalt Amber Crystal
  141680, -- Titan-Forged Locket
  141681, -- Valewalker Talisman
  141682, -- Free Floating Ley Spark
  141683, -- Mana-Injected Chronarch Power Core
  141684, -- Residual Manastorm Energy
  141685, -- The Valewalker's Blessing
  141689, -- Jewel of Victory
  141690, -- Symbol of Victory
  141699, -- Boon of the Companion
  141701, -- Selfless Glory
  141702, -- Spoiled Manawine Dregs
  141703, -- Witch-Harpy Talon
  141704, -- Forgotten Offering
  141705, -- Disorganized Ravings
  141706, -- Carved Oaken Windchimes
  141707, -- Smuggled Magical Supplies
  141708, -- Curio of Neltharion
  141709, -- Ancient Champion Effigy
  141710, -- Discontinued Suramar City Key
  141711, -- Ancient Druidic Carving
  141852, -- Accolade of Heroism
  141853, -- Accolade of Myth
  141854, -- Accolade of Achievement
  141855, -- History of the Aeons
  141856, -- History of the Ages
  141857, -- Soldier's Exertion
  141858, -- Soldier's Worth
  141859, -- Soldier's Splendor
  141863, -- Daglop's Precious
  141872, -- Artisan's Handiwork
  141876, -- Soul-Powered Containment Unit
  141877, -- Coura's Ancient Scepter
  141883, -- Azsharan Keepsake
  141886, -- Crackling Dragonscale
  141887, -- Lucky Brulstone
  141888, -- Discarded Aristocrat's Censer
  141889, -- Glory of the Melee
  141890, -- Petrified Acorn
  141891, -- Branch of Shaladrassil
  141892, -- Gilbert's Finest
  141896, -- Nashal's Spyglass
  141921, -- Desiccated Blue Dragonscale
  141922, -- Brulstone Fishing Sinker
  141923, -- Petrified Axe Haft
  141924, -- Broken Control Mechanism
  141925, -- Pruned Nightmare Shoot
  141926, -- Druidic Molting
  141927, -- Burrowing Worm Mandible
  141928, -- Reaver's Harpoon Head
  141929, -- Hippogryph Plumage
  141930, -- Smolderhide Spirit Beads
  141931, -- Tattered Farondis Heraldry
  141932, -- Shard of Compacted Energy
  141933, -- Citrine Telemancy Index
  141934, -- Partially Enchanted Nightborne Coin
  141935, -- Enchrgled Mlrgmlrg of Enderglment
  141936, -- Petrified Fel-Heart
  141937, -- Eredari Ignition Crystal
  141940, -- Starsong's Bauble
  141941, -- Crystallized Sablehorn Antler
  141942, -- Managazer's Petrifying Eye
  141943, -- Moon Guard Power Gem
  141944, -- Empowered Half-Shell
  141945, -- Magically-Fortified Vial
  141946, -- Trident of Sashj'tar
  141947, -- Mark of Lunastre
  141948, -- Token of a Master Cultivator
  141949, -- Everburning Arcane Glowlamp
  141950, -- Arcane Seed Case
  141951, -- Spellbound Jewelry Box
  141952, -- Delving Deeper by Arcanist Perclanea
  141953, -- Nightglow Energy Vessel
  141954, -- 'Borrowed' Highborne Magi's Chalice
  141955, -- Corrupted Duskmere Crest
  141956, -- Rotten Spellbook
  142001, -- Antler of Cenarius
  142002, -- Dragonscale of the Earth Aspect
  142003, -- Talisman of the Ascended
  142004, -- Nar'thalas Research Tome
  142005, -- Vial of Diluted Nightwell Liquid
  142006, -- Ceremonial Warden Glaive
  142007, -- Omnibus: The Schools of Arcane Magic
  142054, -- Enchanted Nightborne Coin
  142449, -- Unearthed Staff Headpiece
  142450, -- Ley to Fel Power Converter
  142451, -- Overcharged Ward Focus
  142454, -- Viz'aduum's Eye
  142455, -- Demonic Command Shards
  142533, -- Titan's Boon
  142534, -- Plume of the Fallen Val'kyr
  142535, -- Soulcatcher of the Encroaching Mist
  142555, -- Aoire's Crook
  143333, -- Badge of Vengeance
  143486, -- Arcshaper's Barrier
  143487, -- Enchanted Dusk Lily
  143488, -- Enchanted Nightborne Coin
  143498, -- Charged Construct's Finger
  143499, -- Overcharged Infiltrator's Mask
  143533, -- Infused Pit Lord Tusk
  143536, -- Overloaded Scrying Orb
  143538, -- Entangled Telemancy Orb
  143540, -- Undertuned Attunement Crystal
  143677, -- Gladiator's Exultation
  143680, -- Soldier's Esteem
  143713, -- Skirmisher's Mastery
  143714, -- Gladiator's Glory
  143715, -- Gladiator's Revelry
  143716, -- Soldier's Legacy
  143738, -- Flying Hourglass
  143739, -- Mark of the Soulcleaver
  143740, -- Enchanted Sin'dorei Banner
  143741, -- Blessed Kaldorei Banner
  143742, -- Scepter of Kerxan
  143743, -- Highly Charged Mana Clog
  143744, -- Blessed Ravencrest Blades
  143745, -- Ley-Syphoner's Focus
  143746, -- Fel-Dipped Blade
  143747, -- Key to the Nighthold
  143749, -- Corrupted Nightborne Matrix
  143757, -- Headpiece of the Shadow Council
  143844, -- Glory of Combat
  143868, -- Accolade of Achievement
  143869, -- Accolade of Victory
  143870, -- Accolade of Heroism
  143871, -- Accolade of Myth
  144266, -- Shattered Wrathguard Horn
  144267, -- Bloodied Horde Axe Head
  144268, -- Alliance Infantry Blade
  144269, -- Vacant Soul Shard
  144270, -- Fel-Scarred Tomb Stone
  144271, -- Searing Hellion Claw
  144272, -- Seal of Bravery
  144297, -- Talisman of Victory
  146122, -- Warden's Lantern
  146123, -- Enchanted Vault Cell Key
  146124, -- Exhausted Portal Key
  146125, -- Legion Mark of Command
  146126, -- "Revised" Chronicles of Argus
  146127, -- Shard of a Dead World
  146128, -- Nefarious Trophy Jar
  146129, -- Demonic Whetstone
  146309, -- Expended Spell Reagents
  146313, -- Highborne Pottery Shards
  146314, -- Marble Arrowhead
  146315, -- Moon-Rune of Elune
  146316, -- Ancient Suramar Silver
  146318, -- Imp's Femur
  146319, -- Doom Dust
  146320, -- Faded Green Gem
  146321, -- Fossilized Succubus Horn
  146322, -- Fel Toast
  146323, -- Cracked Kobold Skull
  146324, -- Ossified Roc Feather
  146325, -- Worm-Eaten Grain Pouch
  146326, -- Scorched Pyrestone
  146327, -- Petrified Air Totem
  146329, -- Jar of Ashes
  146662, -- Potion of Potion Drinking
  146663, -- Soggy Tapestry
  146664, -- Finely-Jeweled Key
  146671, -- Cubic Zirconia
  147198, -- Gladiator's Exultation
  147199, -- Gladiator's Triumph
  147200, -- Soldier's Glory
  147201, -- Gladiator's Glory
  147202, -- Gladiator's Revelry
  147203, -- Soldier's Legacy
  147398, -- Lesser Pathfinder's Symbol
  147399, -- Lesser Adventurer's Symbol
  147400, -- Lesser Hero's Symbol
  147401, -- Lesser Champion's Symbol
  147402, -- Pathfinder's Symbol
  147403, -- Adventurer's Symbol
  147404, -- Hero's Symbol
  147405, -- Champion's Symbol
  147406, -- Greater Pathfinder's Symbol
  147407, -- Greater Adventurer's Symbol
  147408, -- Greater Hero's Symbol
  147409, -- Greater Champion's Symbol
  147441, -- Sheaf of Royal Stationery
  147442, -- Gilded Prayer Beads
  147444, -- Ravaged Wristclamp Strap
  147456, -- Frostbound Sinew
  147457, -- Spurs of the Risen Horsemen
  147458, -- Mardum Soulcrystal
  147459, -- Reclaimed Ashtongue Feltome
  147460, -- Fang of Goldrinn
  147461, -- Unblemished Leaf of Shaladrassil
  147462, -- Feather of Ohn'ahra
  147463, -- Skyhorn Ritual Drum
  147464, -- Scroll of Tirisgarde Arcana
  147465, -- Mage-Guard Dueling Wand
  147466, -- Chi-Ji Tailfeather
  147467, -- Marble Niuzao Effigy
  147468, -- Memoir of the Broken Temple
  147469, -- Blessed Sculpture of Tyr
  147470, -- Silver Hand Aspirant's Codex
  147471, -- Netherlight Reliquary
  147472, -- Blessed Brooch of the Conclave
  147473, -- Antique Ravenholdt Dagger
  147474, -- Uncrowned Poison Set
  147475, -- Mark of the Aligned Elemental Lords
  147476, -- Everburning Smolderon Ember
  147477, -- Council-Empowered Riftcrystal
  147478, -- Dreadscar Instigator's Broken Soul
  147479, -- Helgar Forged Trophy Blade
  147480, -- Valajar-Sanctified Weapon Polish
  147481, -- Gilded Skyhold Greatshield
  147482, -- Contorted Eredar Bangle
  147483, -- Defiled Moonborn Statuette
  147484, -- Sightless Tormentor's Tome
  147485, -- Wicked Wyrmtongue Fetish
  147486, -- Legionfall Vanguard Battle Standard
  147548, -- Champion's Trophy
  147549, -- Hero's Trophy
  147550, -- Adventurer's Trophy
  147551, -- Pathfinder's Trophy
  147579, -- Tome of the Legionfall Magi
  147581, -- Depleted Azsharan Seal
  147718, -- Master's Symbol
  147719, -- Lesser Master's Symbol
  147720, -- Greater Master's Symbol
  147721, -- Master's Trophy
  147808, -- Lesser Adept's Spoils
  147809, -- Adept's Spoils
  147810, -- Greater Adept's Spoils
  147811, -- Expert's Bounty
  147812, -- Greater Expert's Bounty
  147814, -- Lesser Expert's Bounty
  147818, -- Expert's Crest
  147819, -- Adept's Medal
  147842, -- Unity of the Orders
  150931, -- Seal of Authority
  151240, -- Corroded Hologram Crystal
  151241, -- Blistering Infernal Fragment
  151242, -- Pious Anchorite's Breviary
  151243, -- Soulgorged Felglobe
  151244, -- Legion Doom-Horn
  151245, -- Novitiate's Tarnished Arcanoscope
  151246, -- Fel-Imbued Artillery Catalyst
  151247, -- Lightguard Battle Medal
  151556, -- Spoils of the Triumphant
  151561, -- Bauble of the Triumphant
  151619, -- Prize of the Triumphant
  151620, -- Humming Shard
  151696, -- Crumbling Bust
  151697, -- Chromie's Eighth Spare Pocketwatch
  151698, -- Sinister Signet Ring
  151699, -- Scrimshawed Dragonbone Paperweight
  151700, -- Wayfinder's Sundial
  151789, -- Defense Construct Identifier
  151914, -- Gladiator's Perseverance
  151915, -- Gladiator's Perseverance
  151916, -- Gladiator's Perseverance
  151917, -- Gladiator's Perseverance
  151918, -- Gladiator's Perseverance
  151919, -- Gladiator's Perseverance
  151920, -- Gladiator's Perseverance
  151921, -- Gladiator's Perseverance
  151922, -- Gladiator's Perseverance
  152430, -- Krokul Hovel Chronicle
  152431, -- Shadowguard Harvester
  152432, -- Stasis Core Crystal
  152433, -- Smoldering Infernal Stone
  152434, -- Praetorium Edict
  152435, -- Aranasi Mandible
  152504, -- Shattered Seal of the Unrepentant Guardian
  152651, -- Crumbling Chronicles of Argus
  152653, -- Virtue of the Light
  152654, -- Lesser Unity of the Orders
  152700, -- Krokul Battle Horn
  152706, -- Sanctified Warrior Memento
  152707, -- Lightforged Cannon Projectile
  152708, -- ERROR1
  152709, -- Partially Charged Conduit
  152710, -- Ruined Conservatory Emblem
  152711, -- Light-Smote Skullplate
  152712, -- Sanctified Prayer Effigy
  152713, -- Discarded Remnant of the Void
  152937, -- Dendrite Flux
  152938, -- Emblazoned Shadowguard Insignia
  152939, -- Mark of the Triumvirate Warriors
  152962, -- Voidcore Control Rod
  152984, -- Boon of the Pantheon
  153001, -- Faintly Glowing Phoenix Down
  153007, -- Rite-Blessed Sheath
  153008, -- Timeworn Amethyst Figurine
  153009, -- Brazier of the Faithful
  153046, -- Duskcloak Dorsal Plate
  153047, -- Talbuk Bridle
  153048, -- Phial of 'Sacred' Fel Liquid
  153052, -- Depleted Pylon Core
  153159, -- Void-Swallowed Memento
  153160, -- Crude Effigy of Despair
  153161, -- Incomprehensible Scribbling
  153162, -- Unattuned Portal Stones
  153163, -- Gruesome Wind Chime
  153164, -- Otherworldly Trophy
  153165, -- Krokul Remembrance-Crystal
  153198, -- Rimy Hailstone
  153199, -- Chillward Brazier
  153200, -- Shimmering Floatroot
  153201, -- Glinting Aurinor Dewdrops
  153217, -- Emblazoned Fire Core
  153218, -- Primordial Giant's Heart
  153220, -- Blood Drainer Globe
  153221, -- Congealed Animus Plasma
  153222, -- Hallowed Glade Pinecone
  153223, -- Shed Antlers of Elkeirnir
  153224, -- Luminescent Moonshroom
  153225, -- Naigtal Shambler Eye
  153246, -- Strangely-Flawed Gemstone
  153259, -- Legion General's Medallion of Command
  153266, -- Undulating Orb of Fel Inferno
  153278, -- Vile Temptresses' Aphrodisiac
}

-- Broken Shore
local BrokenShore_IDs = {
  142452, -- Lingering Wyrmtongue Essence
  143559, -- Wyrmtongue's Cache Key
  146903, -- Sentinax Beacon of Domination
  146905, -- Sentinax Beacon of the Firestorm
  146906, -- Sentinax Beacon of Carnage
  146907, -- Sentinax Beacon of Warbeasts
  146908, -- Sentinax Beacon of Engineering
  146909, -- Sentinax Beacon of Torment
  146910, -- Sentinax Beacon of Greater Domination
  146911, -- Sentinax Beacon of the Greater Firestorm
  146912, -- Sentinax Beacon of Greater Carnage
  146913, -- Sentinax Beacon of Greater Warbeasts
  146914, -- Sentinax Beacon of Greater Engineering
  146915, -- Sentinax Beacon of Greater Torment
  146916, -- Portal-Stone: Than'otalion
  146917, -- Portal-Stone: Skulguloth
  146918, -- Portal-Stone: Force-Commander Xillious
  146919, -- Portal-Stone: An'thyna
  146920, -- Portal-Stone: Fel Obliterator
  146921, -- Portal-Stone: Illisthyndria
  146922, -- Sentinax Beacon of Fel Growth
  146923, -- Sentinax Beacon of Petrification
  147355, -- Sentinax Beacon of the Bloodstrike
  147384, -- Legionfall Recompense
  147726, -- Nethercluster
  147729, -- Netherchunk
  147889, -- Attack Beacon: Illidari Stand
  147891, -- Attack Beacon: Starsong Refuge
  147892, -- Attack Beacon: Skyhorn
  147893, -- Attack Beacon: Stormtorn Foothills
  147894, -- Attack Beacon: Dalaran Underbelly
}

-- Reputation
local Reputation_IDs = {
  139020, -- Valarjar Insignia
  139021, -- Dreamweaver Insignia
  139023, -- Court of Farondis Insignia
  139024, -- Highmountain Tribe Insignia
  139025, -- Wardens Insignia
  139026, -- Nightfallen Insignia
  140260, -- Arcane Remnant of Falanaar
  141338, -- Valarjar Insignia
  141339, -- Dreamweaver Insignia
  141340, -- Court of Farondis Insignia
  141341, -- Highmountain Tribe Insignia
  141342, -- Wardens Insignia
  141343, -- Nightfallen Insignia
  141870, -- Arcane Tablet of Falanaar
  141987, -- Greater Valarjar Insignia
  141988, -- Greater Dreamweaver Insignia
  141989, -- Greater Court of Farondis Insignia
  141990, -- Greater Highmountain Tribe Insignia
  141991, -- Greater Wardens Insignia
  141992, -- Greater Nightfallen Insignia
  146935, -- Valarjar Insignia
  146936, -- Dreamweaver Insignia
  146937, -- Court of Farondis Insignia
  146938, -- Highmountain Tribe Insignia
  146939, -- Wardens Insignia
  146940, -- Nightfallen Insignia
  146941, -- Valarjar Insignia
  146942, -- Dreamweaver Insignia
  146943, -- Court of Farondis Insignia
  146944, -- Highmountain Tribe Insignia
  146945, -- Wardens Insignia
  146946, -- Nightfallen Insignia
  146949, -- Legionfall Insignia
  146950, -- Legionfall Insignia
  147410, -- Greater Court of Farondis Insignia
  147411, -- Greater Dreamweaver Insignia
  147412, -- Greater Highmountain Tribe Insignia
  147413, -- Greater Nightfallen Insignia
  147414, -- Greater Valarjar Insignia
  147415, -- Greater Wardens Insignia
  147416, -- Arcane Tablet of Falanaar
  147418, -- Arcane Remnant of Falanaar
  147727, -- Greater Legionfall Insignia
  150925, -- Greater Valarjar Insignia
  150926, -- Greater Dreamweaver Insignia
  150927, -- Greater Court of Farondis Insignia
  150928, -- Greater Highmountain Tribe Insignia
  150929, -- Greater Wardens Insignia
  150930, -- Greater Nightfallen Insignia
  152464, -- Greater Legionfall Insignia
  152954, -- Greater Argussian Reach Insignia
  152955, -- Greater Army of the Light Insignia
  152956, -- Greater Army of the Light Insignia
  152957, -- Army of the Light Insignia
  152958, -- Army of the Light Insignia
  152959, -- Argussian Reach Insignia
  152960, -- Argussian Reach Insignia
  152961, -- Greater Argussian Reach Insignia
  153113, -- Demon's Soulstone
}

local function converttohex(rgb)
  return string.format("%02x%02x%02x", rgb.r * 255, rgb.g * 255, rgb.b * 255)
end

local function converttorgb(hex, as_table)
  if as_table then
    return {
      r = tonumber("0x" .. strsub(hex, 1, 2)) / 255,
      g = tonumber("0x" .. strsub(hex, 3, 4)) / 255,
      b = tonumber("0x" .. strsub(hex, 5, 6)) / 255,
    }
  else
    -- as 3 values
    return tonumber("0x" .. hex:sub(1, 2)) / 255,
      tonumber("0x" .. hex:sub(3, 4)) / 255,
      tonumber("0x" .. hex:sub(5, 6)) / 255
  end
end


local function formatBagTitle(self, title, hex)
  local prefix = ""
  if self.db.profile.prefixCategories then
    if self.db.profile.prefixCategories == "!CUSTOM" then
      prefix = self.db.profile.customPrefix
    else
      prefix = self.db.profile.prefixCategories
    end
  end
  if self.db.profile.coloredPrefix then
    prefix = "|cff" .. converttohex(self.db.profile.color.prefix) .. prefix .. "|r"
    if self.db.profile.coloredCategories then
      return prefix .. "|cff" .. hex .. title .. "|r"
    else
      return prefix .. title
    end
  else
    if self.db.profile.coloredCategories then
      return prefix .. "|cff" .. hex .. title .. "|r"
    else
      return prefix .. title
    end
  end
end

local function MatchIDs_Init(self)
  wipe(Result)

  if self.db.profile.moveMergedChampionUpgrades then
    Result[formatBagTitle(self, L["Champion Upgrades"], converttohex(self.db.profile.color.mergedChampionUpgrades))] =
      AddToSet(ChampionEquipment_IDs, ChampionUpgradeTokens_IDs)
  else
    if self.db.profile.moveChampionEquipment then
      Result[formatBagTitle(self, L["Champion Equipment"], converttohex(self.db.profile.color.ChampionEquipment))] =
        AddToSet(ChampionEquipment_IDs)
    end
    if self.db.profile.moveChampionUpgradeTokens then
      Result[formatBagTitle(
        self,
        L["Champion Upgrade Tokens"],
        converttohex(self.db.profile.color.ChampionUpgradeTokens)
      )] =
        AddToSet(ChampionUpgradeTokens_IDs)
    end
  end
  if self.db.profile.moveMergedFishingGoods then
    Result[formatBagTitle(self, L["Fishing Goods"], converttohex(self.db.profile.color.mergedFishingGoods))] =
      AddToSet(FishingBait_IDs, RareFish_IDs)
  else
    if self.db.profile.moveFishingBait then
      Result[formatBagTitle(self, L["Fishing Bait"], converttohex(self.db.profile.color.FishingBait))] =
        AddToSet(FishingBait_IDs)
    end
    if self.db.profile.moveRareFish then
      Result[formatBagTitle(self, L["Rare Fish"], converttohex(self.db.profile.color.RareFish))] =
        AddToSet(RareFish_IDs)
    end
  end
  if self.db.profile.moveAncientMana then
    Result[formatBagTitle(self, L["Ancient Mana"], converttohex(self.db.profile.color.AncientMana))] =
      AddToSet(AncientMana_IDs)
  end
  if self.db.profile.moveArtifactPower then
    Result[formatBagTitle(self, L["Artifact Power"], converttohex(self.db.profile.color.ArtifactPower))] =
      AddToSet(ArtifactPower_IDs)
  end
  if self.db.profile.moveBrokenShore then
    Result[formatBagTitle(self, L["Broken Shore"], converttohex(self.db.profile.color.BrokenShore))] =
      AddToSet(BrokenShore_IDs)
  end
  if self.db.profile.moveReputation then
    Result[formatBagTitle(self, L["Reputation"], converttohex(self.db.profile.color.Reputation))] =
      AddToSet(Reputation_IDs)
  end

  return Result
end

local setFilter = AdiBags:RegisterFilter("Legion", 98, "ABEvent-1.0")
setFilter.uiName = string.format("|cff00bd16%s|r", L["Legion"])
setFilter.uiDesc =
  string.format("%s\n|cffffd800%s: 2.0.1|r", L["Items from the Legion expansion."], L["Filter version"])

function setFilter:OnInitialize()
  self.db = AdiBags.db:RegisterNamespace("Legion", {
    profile = {
      coloredCategories = true,
      prefixCategories = "",
      customPrefix = "",
      coloredPrefix = true,
      moveMergedChampionUpgrades = true,
      moveChampionEquipment = true,
      moveChampionUpgradeTokens = true,
      moveMergedFishingGoods = true,
      moveFishingBait = true,
      moveRareFish = true,
      moveAncientMana = true,
      moveArtifactPower = false,
      moveBrokenShore = true,
      moveReputation = true,

      color = {
        prefix = converttorgb("00bd16", true),
        mergedChampionUpgrades = converttorgb("3d5f86", true),
        ChampionEquipment = converttorgb("00bd2c", true),
        ChampionUpgradeTokens = converttorgb("7900df", true),
        mergedFishingGoods = converttorgb("009fff", true),
        FishingBait = converttorgb("00c0ff", true),
        RareFish = converttorgb("007eff", true),
        AncientMana = converttorgb("636aff", true),
        ArtifactPower = converttorgb("707070", true),
        BrokenShore = converttorgb("000455", true),
        Reputation = converttorgb("005510", true),
      },
    },
  })
end

function setFilter:Update()
  MatchIDs = nil
  self:SendMessage("AdiBags_FiltersChanged")
end

function setFilter:OnEnable()
  AdiBags:UpdateFilters()
end

function setFilter:OnDisable()
  AdiBags:UpdateFilters()
end

function setFilter:Filter(slotData)
  MatchIDs = MatchIDs or MatchIDs_Init(self)
  for i, name in pairs(MatchIDs) do
    -- Override Method
    if MatchIDs[i]["override"] then
      slotData["loc"] = ItemLocation:CreateFromBagAndSlot(slotData.bag, slotData.slot)
      if slotData["loc"] and slotData["loc"]:IsValid() then
        if MatchIDs[i]["override"](slotData.loc) then
          return i
        end
      end

      -- Bonus Condition (triggers when bonus condition is not fulfilled)
    elseif MatchIDs[i]["bonus_condition"] then
      if name[slotData.itemId] then
        slotData["loc"] = ItemLocation:CreateFromBagAndSlot(slotData.bag, slotData.slot)
        if slotData["loc"] and slotData["loc"]:IsValid() then
          if not MatchIDs[i]["bonus_condition"](slotData.loc) then
            -- THERE IS A NOT HERE!
            return i
          end
        end
      end

      -- Standard ID Matching
    elseif name[slotData.itemId] then
      return i
    end
  end
end

function setFilter:GetOptions()
  return {
    general_config = {
      type = "group",
      name = L["General Settings"],
      desc = L["Settings affecting all categories."],
      inline = true,
      order = 1,
      args = {
        description = {
          type = "description",
          name = string.format(
            "%s |cffffd800%s |cff529F00%s|r",
            L["These settings affect all categories of this filter."],
            L["If you overwrite prefix or categorie color, you either need to toggle the color setting twice or reload."],
            L["AdiBags never intended to use icons, so they are glitchy. Make sure to disable prefix color, if you use an icon."]
          ),
          order = 1,
        },
        coloredCategories = {
          name = string.format("|cffFDFD96%s|r", L["Colored Categories"]),
          desc = L["Should Categories be colored?"],
          width = "full",
          type = "toggle",
          order = 10,
        },
        prefixCategories = {
          name = L["Prefix Categories"],
          desc = L["Select a prefix for the categories, if you like."],
          type = "select",
          order = 20,
          values = {
            [""] = L["None"],
            ["!CUSTOM"] = L["Custom Prefix"],
            ["LE"] = "LE",
            ["LG"] = "LG",
            ["LE-"] = "LE-",
            ["LG-"] = "LG-",
            ["6."] = "6.",
            ["|T1387636:" .. AdiBags.HEADER_SIZE .. ":" .. AdiBags.HEADER_SIZE .. ":-2:-10|t"] = "|T1387636:"
              .. AdiBags.HEADER_SIZE
              .. "|t",
            ["|T1713484:" .. AdiBags.HEADER_SIZE .. ":" .. AdiBags.HEADER_SIZE .. ":-2:-10|t"] = "|T1713484:"
              .. AdiBags.HEADER_SIZE
              .. "|t",
            ["|T1394946:" .. AdiBags.HEADER_SIZE .. ":" .. AdiBags.HEADER_SIZE .. ":-2:-10|t"] = "|T1394946:"
              .. AdiBags.HEADER_SIZE
              .. "|t",
            ["|T1500941:" .. AdiBags.HEADER_SIZE .. ":" .. AdiBags.HEADER_SIZE .. ":-2:-10|t"] = "|T1500941:"
              .. AdiBags.HEADER_SIZE
              .. "|t",
            ["|T1500909:" .. AdiBags.HEADER_SIZE .. ":" .. AdiBags.HEADER_SIZE .. ":-2:-10|t"] = "|T1500909:"
              .. AdiBags.HEADER_SIZE
              .. "|t",
            ["|T1500904:" .. AdiBags.HEADER_SIZE .. ":" .. AdiBags.HEADER_SIZE .. ":-2:-10|t"] = "|T1500904:"
              .. AdiBags.HEADER_SIZE
              .. "|t",
            ["|T1500899:" .. AdiBags.HEADER_SIZE .. ":" .. AdiBags.HEADER_SIZE .. ":-2:-10|t"] = "|T1500899:"
              .. AdiBags.HEADER_SIZE
              .. "|t",
            ["|T236293:" .. AdiBags.HEADER_SIZE .. ":" .. AdiBags.HEADER_SIZE .. ":-2:-10|t"] = "|T236293:"
              .. AdiBags.HEADER_SIZE
              .. "|t",
            ["|T1305156:" .. AdiBags.HEADER_SIZE .. ":" .. AdiBags.HEADER_SIZE .. ":-2:-10|t"] = "|T1305156:"
              .. AdiBags.HEADER_SIZE
              .. "|t",
            ["|T1392554:" .. AdiBags.HEADER_SIZE .. ":" .. AdiBags.HEADER_SIZE .. ":-2:-10|t"] = "|T1392554:"
              .. AdiBags.HEADER_SIZE
              .. "|t",
            ["|T1450140:" .. AdiBags.HEADER_SIZE .. ":" .. AdiBags.HEADER_SIZE .. ":-2:-10|t"] = "|T1450140:"
              .. AdiBags.HEADER_SIZE
              .. "|t",
          },
        },
        customPrefix = {
          name = L["Custom Prefix"],
          desc = L["Enter a custom prefix for the categories."],
          type = "input",
          order = 30,
          width = "full",
          disabled = function()
            return self.db.profile.prefixCategories ~= "!CUSTOM"
          end,
        },
        coloredPrefix = {
          name = string.format("|cffB9FFB9%s|r", L["Colored Prefix"]),
          desc = L["Should the prefix be colored to the filter color? (Only works for text-prefixes, for obvious reasons.)"],
          type = "toggle",
          order = 40,
        },
        prefixColor = {
          name = L["Prefix Color"],
          desc = L["Select a color for the prefix."],
          type = "color",
          order = 50,
          hasAlpha = false,
          disabled = function()
            return not self.db.profile.coloredPrefix
          end,
          get = function()
            local color = self.db.profile.color.prefix
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.prefix
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
      },
    },
    ChampionUpgrades_config = {
      type = "group",
      name = L["Champion Upgrades"],
      desc = "", -- doesnt work,
      inline = true,
      order = 52,
      args = {
        Legendaries_desc = {
          type = "description",
          name = L["Items used to upgrade your Legion champions"],
          order = 53,
        },
        moveMergedChampionUpgrades = {
          name = string.format(L["%sMerge %s%s"], "|cffffd800", L["Champion Upgrades"], "|r"),
          desc = string.format(L["Merge all %s into a single category."], L["Champion Upgrades"]),
          type = "toggle",
          width = 1.5,
          order = 54,
        },
        colorMergedChampionUpgrades = {
          name = L["Color"],
          desc = string.format(L["Select a color for the merged %s category."], L["Champion Upgrades"]),
          type = "color",
          order = 55,
          hasAlpha = false,
          disabled = function()
            return not self.db.profile.moveMergedChampionUpgrades
          end,
          get = function()
            local color = self.db.profile.color.mergedChampionUpgrades
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.mergedChampionUpgrades
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_1 = {
          type = "header",
          name = "",
          order = 56,
        },
        moveChampionEquipment = {
          name = L["Champion Equipment"],
          desc = L["Champion Equipment to improve your Champions"],
          type = "toggle",
          width = 1.5,
          order = 57,
          disabled = function()
            return self.db.profile.moveMergedChampionUpgrades
          end,
        },
        colorChampionEquipment = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Champion Equipment"]),
          type = "color",
          order = 58,
          disabled = function()
            return self.db.profile.moveMergedChampionUpgrades
          end,
          get = function()
            local color = self.db.profile.color.ChampionEquipment
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.ChampionEquipment
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_2 = {
          type = "header",
          name = "",
          order = 59,
        },
        moveChampionUpgradeTokens = {
          name = L["Champion Upgrade Tokens"],
          desc = L["Items used for upgrading your Champion"],
          type = "toggle",
          width = 1.5,
          order = 60,
          disabled = function()
            return self.db.profile.moveMergedChampionUpgrades
          end,
        },
        colorChampionUpgradeTokens = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Champion Upgrade Tokens"]),
          type = "color",
          order = 61,
          disabled = function()
            return self.db.profile.moveMergedChampionUpgrades
          end,
          get = function()
            local color = self.db.profile.color.ChampionUpgradeTokens
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.ChampionUpgradeTokens
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
      },
    },
    FishingGoods_config = {
      type = "group",
      name = L["Fishing Goods"],
      desc = "", -- doesnt work,
      inline = true,
      order = 62,
      args = {
        Legendaries_desc = {
          type = "description",
          name = L["Something is fishy about this category."],
          order = 63,
        },
        moveMergedFishingGoods = {
          name = string.format(L["%sMerge %s%s"], "|cffffd800", L["Fishing Goods"], "|r"),
          desc = string.format(L["Merge all %s into a single category."], L["Fishing Goods"]),
          type = "toggle",
          width = 1.5,
          order = 64,
        },
        colorMergedFishingGoods = {
          name = L["Color"],
          desc = string.format(L["Select a color for the merged %s category."], L["Fishing Goods"]),
          type = "color",
          order = 65,
          hasAlpha = false,
          disabled = function()
            return not self.db.profile.moveMergedFishingGoods
          end,
          get = function()
            local color = self.db.profile.color.mergedFishingGoods
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.mergedFishingGoods
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_3 = {
          type = "header",
          name = "",
          order = 66,
        },
        moveFishingBait = {
          name = L["Fishing Bait"],
          desc = L["Fishing bait used for Legion rare fishes"],
          type = "toggle",
          width = 1.5,
          order = 67,
          disabled = function()
            return self.db.profile.moveMergedFishingGoods
          end,
        },
        colorFishingBait = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Fishing Bait"]),
          type = "color",
          order = 68,
          disabled = function()
            return self.db.profile.moveMergedFishingGoods
          end,
          get = function()
            local color = self.db.profile.color.FishingBait
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.FishingBait
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_4 = {
          type = "header",
          name = "",
          order = 69,
        },
        moveRareFish = {
          name = L["Rare Fish"],
          desc = L["Rare Fish caught in the Broken Isles"],
          type = "toggle",
          width = 1.5,
          order = 70,
          disabled = function()
            return self.db.profile.moveMergedFishingGoods
          end,
        },
        colorRareFish = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Rare Fish"]),
          type = "color",
          order = 71,
          disabled = function()
            return self.db.profile.moveMergedFishingGoods
          end,
          get = function()
            local color = self.db.profile.color.RareFish
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.RareFish
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
      },
    },
    OtherItems_config = {
      type = "group",
      name = L["Other Items"],
      desc = "", -- doesnt work,
      inline = true,
      order = 72,
      args = {
        Legendaries_desc = {
          type = "description",
          name = L["Other items not really fitting in another category"],
          order = 73,
        },
        moveAncientMana = {
          name = L["Ancient Mana"],
          desc = L["Ancient Mana, found and used in Sumeru."],
          type = "toggle",
          width = 1.5,
          order = 74,
        },
        colorAncientMana = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Ancient Mana"]),
          type = "color",
          order = 75,
          disabled = function()
            return self.db.profile.moveMergedOtherItems
          end,
          get = function()
            local color = self.db.profile.color.AncientMana
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.AncientMana
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_5 = {
          type = "header",
          name = "",
          order = 76,
        },
        moveArtifactPower = {
          name = L["Artifact Power"],
          desc = L["Items which were used to grant your weapon artifact power (but are now grey vendor trash)"],
          type = "toggle",
          width = 1.5,
          order = 77,
        },
        colorArtifactPower = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Artifact Power"]),
          type = "color",
          order = 78,
          disabled = function()
            return self.db.profile.moveMergedOtherItems
          end,
          get = function()
            local color = self.db.profile.color.ArtifactPower
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.ArtifactPower
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_6 = {
          type = "header",
          name = "",
          order = 79,
        },
        moveBrokenShore = {
          name = L["Broken Shore"],
          desc = L["Items from the Broken Shore Zone"],
          type = "toggle",
          width = 1.5,
          order = 80,
        },
        colorBrokenShore = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Broken Shore"]),
          type = "color",
          order = 81,
          disabled = function()
            return self.db.profile.moveMergedOtherItems
          end,
          get = function()
            local color = self.db.profile.color.BrokenShore
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.BrokenShore
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_7 = {
          type = "header",
          name = "",
          order = 82,
        },
        moveReputation = {
          name = L["Reputation"],
          desc = L["Items used to increase Reputation with Legion factions"],
          type = "toggle",
          width = 1.5,
          order = 83,
        },
        colorReputation = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Reputation"]),
          type = "color",
          order = 84,
          disabled = function()
            return self.db.profile.moveMergedOtherItems
          end,
          get = function()
            local color = self.db.profile.color.Reputation
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.Reputation
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
      },
    },
  },
    AdiBags:GetOptionHandler(self, false, function()
      return self:Update()
    end)
end
